@@ -3,7 +3,7 @@
 |''Description:''|Formatter to reference other spaces from wikitext |
 |''Author:''|PaulDowney (psd (at) osmosoft (dot) com) |
 |''Source:''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/TiddlySpaceLinkPlugin.js|
-|''Version:''|1.3.1|
+|''Version:''|1.4.1|
 |''License:''|[[BSD License|http://www.opensource.org/licenses/bsd-license.php]] |
 |''Comments:''|Please make comments at http://groups.google.co.uk/group/TiddlyWikiDev |
 |''~CoreVersion:''|2.4|
@@ -50,8 +50,10 @@ function createSpaceLink(place, spaceName, title, alt, isBag) {
 		currentSpaceName = false;
 	}
 
-	a = jQuery("<a />").addClass('tiddlySpaceLink externalLink').attr('tiddler', title).
-		appendTo(place)[0];
+	a = jQuery("<a />").addClass('tiddlySpaceLink externalLink').appendTo(place)[0];
+	if(title) {
+		jQuery(a).attr('tiddler', title);
+	}
 	if(isBag) {
 		jQuery(a).attr('bag', spaceName);
 	} else {
