@@ -3,13 +3,9 @@ https://github.com/tiddlyweb/chrjs/raw/master/main.js
 ***/
 //{{{
 // TiddlyWeb adaptor
-// v0.12.0
-//
-// TODO:
-// * ensure all routes are supported
-// * documentation
+// v0.14.2
 
-/*jslint vars: true, unparam: true, nomen: true */
+/*jslint vars: true, unparam: true, nomen: true, white: true */
 /*global jQuery */
 
 var tiddlyweb = (function($) {
@@ -74,13 +70,12 @@ $.extend(tw.Resource.prototype, {
 	// callback is passed data, status, XHR (cf. jQuery.ajax success)
 	// errback is passed XHR, error, exception, resource (cf. jQuery.ajax error)
 	put: function(callback, errback) {
-		var self = this,
-			uri = this.route();
+		var self = this;
 		var options = {
-			url: uri,
+			url: this.route(),
 			type: "PUT",
 			contentType: "application/json",
-			data: this.toJSON(),
+			data: JSON.stringify(this.baseData()),
 			success: function(data, status, xhr) {
 				callback(self, status, xhr);
 			},
@@ -97,10 +92,9 @@ $.extend(tw.Resource.prototype, {
 	// callback is passed data, status, XHR (cf. jQuery.ajax success)
 	// errback is passed XHR, error, exception, resource (cf. jQuery.ajax error)
 	"delete": function(callback, errback) {
-		var self = this,
-			uri = this.route();
+		var self = this;
 		var options = {
-			url: uri,
+			url: this.route(),
 			type: "DELETE",
 			success: function(data, status, xhr) {
 				callback(self, status, xhr);
@@ -114,8 +108,8 @@ $.extend(tw.Resource.prototype, {
 		}
 		return $.ajax(options);
 	},
-	// returns the JSON representation of a resource
-	toJSON: function() {
+	// returns an object carrying only the essential information of the resource
+	baseData: function() {
 		var data = {},
 			self = this;
 		$.each(this.data, function(i, item) {
@@ -124,9 +118,9 @@ $.extend(tw.Resource.prototype, {
 				data[item] = value;
 			}
 		});
-		return JSON.stringify(data);
+		return data;
 	},
-	// returns corresponding instance from raw JSON object (if applicable)
+	// returns corresponding instance from a raw object (if applicable)
 	parse: function(data) {
 		return data;
 	},
@@ -259,12 +253,14 @@ $.extend(tw.Tiddler.prototype, {
 	parse: function(data) {
 		var tiddler = new tw.Tiddler(this.title),
 			container = this.bag || this.recipe;
-		tiddler.bag = new tw.Bag(data.bag, container.host);
-		delete data.bag;
+		if(data.bag) {
+			tiddler.bag = new tw.Bag(data.bag, container.host);
+			delete data.bag;
+		}
 		delete data.recipe;
-		tiddler.created = convertTimestamp(data.created);
+		tiddler.created = data.created ? convertTimestamp(data.created) : new Date();
 		delete data.created;
-		tiddler.modified = convertTimestamp(data.modified);
+		tiddler.modified = data.modified ? convertTimestamp(data.modified) : new Date();
 		delete data.modified;
 		if(this.recipe) {
 			tiddler.recipe = this.recipe;
